#!/bin/bash

ARCH=$(uname -m)
MAIN_DIR=FreeCAD
BUILD_DIR=build

echo "Architecture: $ARCH"
echo "Main directory: $MAIN_DIR"
echo "Build directory: $BUILD_DIR"

REL_FILE=/etc/redhat-release

if [ -d "$MAIN_DIR" ]
then
	echo "Main directory $MAIN_DIR already exists! Please remove it or use a different directory to start building"
	exit 1
fi

if [ -d "$BUILD_DIR" ]
then
	echo "Build directory $BUILD_DIR already exists! Please remove it or use a different directory to start building"
	exit 1
fi

if [ -f "$REL_FILE" ]
then
	cat $REL_FILE | grep 20 && FEDORA_VERSION=20
	cat $REL_FILE | grep 21 && FEDORA_VERSION=21
	cat $REL_FILE | grep 22 && FEDORA_VERSION=22
else
	echo "Cannot figure out release from $REL_FILE!"
	exit 1
fi

echo "Installing packages required to build FreeCAD"
sudo yum -y install gcc cmake gcc-c++ boost-devel zlib-devel swig eigen3 qt-devel \
   shiboken shiboken-devel pyside-tools python-pyside python-pyside-devel xerces-c \
   xerces-c-devel OCE-devel smesh graphviz python-pivy python-matplotlib tbb-devel \
   freeimage-devel Coin3 Coin3-devel

mkdir $MAIN_DIR
cd $MAIN_DIR
git clone https://github.com/FreeCAD/FreeCAD_sf_master.git

mkdir $BUILD_DIR
cd $BUILD_DIR
cmake ../FreeCAD_sf_master && make
